//Copyright 2005 Nokia Corporation.
//
// THIS SOURCE CODE IS PROVIDED 'AS IS', WITH NO WARRANTIES WHATSOEVER,
// EXPRESS OR IMPLIED, INCLUDING ANY WARRANTY OF MERCHANTABILITY, FITNESS
// FOR ANY PARTICULAR PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE
// OR TRADE PRACTICE, RELATING TO THE SOURCE CODE OR ANY WARRANTY OTHERWISE
// ARISING OUT OF ANY PROPOSAL, SPECIFICATION, OR SAMPLE AND WITH NO
// OBLIGATION OF NOKIA TO PROVIDE THE LICENSEE WITH ANY MAINTENANCE OR
// SUPPORT. FURTHERMORE, NOKIA MAKES NO WARRANTY THAT EXERCISE OF THE
// RIGHTS GRANTED HEREUNDER DOES NOT INFRINGE OR MAY NOT CAUSE INFRINGEMENT
// OF ANY PATENT OR OTHER INTELLECTUAL PROPERTY RIGHTS OWNED OR CONTROLLED
// BY THIRD PARTIES
//
// Furthermore, information provided in this source code is preliminary,
// and may be changed substantially prior to final release. Nokia Corporation
// retains the right to make changes to this source code at
// any time, without notice. This source code is provided for informational
// purposes only.
//
// Nokia and Nokia Connecting People are registered trademarks of Nokia
// Corporation.
// Java and all Java-based marks are trademarks or registered trademarks of
// Sun Microsystems, Inc.
// Other product and company names mentioned herein may be trademarks or
// trade names of their respective owners.
//
// A non-exclusive, non-transferable, worldwide, limited license is hereby
// granted to the Licensee to download, print, reproduce and modify the
// source code. The licensee has the right to market, sell, distribute and
// make available the source code in original or modified form only when
// incorporated into the programs developed by the Licensee. No other
// license, express or implied, by estoppel or otherwise, to any other
// intellectual property rights is granted herein.
package example.capitals;

import javax.microedition.midlet.MIDlet;
import javax.microedition.midlet.MIDletStateChangeException;

import example.capitals.ui.*;

/**
 * Main MIDlet class. This class takes care of handling the Display
 * and listen for the result of WebServices requests
 */
public class CapitalMIDlet extends MIDlet implements PosterListener {

    // screen which is displayed at the moment
	private Screen currentScreen;
	// location of the web service
	private String endPoint;
	
	protected void startApp() throws MIDletStateChangeException {
		endPoint = getAppProperty("endPoint");
		// create a new WelcomeScreen and set it active
		changeScreen(new WelcomeScreen(this));		
	}
	
	protected void destroyApp(boolean unconditional) throws MIDletStateChangeException {
	}

	protected void pauseApp() {
	}

	/**
	 * Change the currently active screen
	 */	
	void changeScreen(Screen screen) {		
		currentScreen = screen;
		screen.makeActive();
	}
	
	/**
	 * Called to force termination of MIDlet
     */
	public void quit()
	{    	
		notifyDestroyed();
	}
    
	/**
	 * This method calls the web service
	 */
	public void requestCapital(String country) {
		changeScreen(new WaitingScreen(this));
		Poster poster = new Poster(this, endPoint);
		poster.requestCapital(country);
	}
    
	public void showMainScreen() {
		changeScreen(new MainScreen(this));
	}

	/**
	 * Called when a valid result is retrieved from the
	 * WebService
	 */
	public void onCapitalRequestComplete(String nation, String capital){
		changeScreen(new ResultScreen(this, nation, capital)); 
	}

	/**
	 * Called when an error happens during the WebService call
	 */
	public void onCapitalRequestError(String code){
		changeScreen(new ErrorScreen(this, code));
	}
	
}
