//Copyright 2005 Nokia Corporation.
//
// THIS SOURCE CODE IS PROVIDED 'AS IS', WITH NO WARRANTIES WHATSOEVER,
// EXPRESS OR IMPLIED, INCLUDING ANY WARRANTY OF MERCHANTABILITY, FITNESS
// FOR ANY PARTICULAR PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE
// OR TRADE PRACTICE, RELATING TO THE SOURCE CODE OR ANY WARRANTY OTHERWISE
// ARISING OUT OF ANY PROPOSAL, SPECIFICATION, OR SAMPLE AND WITH NO
// OBLIGATION OF NOKIA TO PROVIDE THE LICENSEE WITH ANY MAINTENANCE OR
// SUPPORT. FURTHERMORE, NOKIA MAKES NO WARRANTY THAT EXERCISE OF THE
// RIGHTS GRANTED HEREUNDER DOES NOT INFRINGE OR MAY NOT CAUSE INFRINGEMENT
// OF ANY PATENT OR OTHER INTELLECTUAL PROPERTY RIGHTS OWNED OR CONTROLLED
// BY THIRD PARTIES
//
// Furthermore, information provided in this source code is preliminary,
// and may be changed substantially prior to final release. Nokia Corporation
// retains the right to make changes to this source code at
// any time, without notice. This source code is provided for informational
// purposes only.
//
// Nokia and Nokia Connecting People are registered trademarks of Nokia
// Corporation.
// Java and all Java-based marks are trademarks or registered trademarks of
// Sun Microsystems, Inc.
// Other product and company names mentioned herein may be trademarks or
// trade names of their respective owners.
//
// A non-exclusive, non-transferable, worldwide, limited license is hereby
// granted to the Licensee to download, print, reproduce and modify the
// source code. The licensee has the right to market, sell, distribute and
// make available the source code in original or modified form only when
// incorporated into the programs developed by the Licensee. No other
// license, express or implied, by estoppel or otherwise, to any other
// intellectual property rights is granted herein.
package example.capitals;

import javax.xml.rpc.Stub;
import java.rmi.RemoteException;

/**
 * The Poster class does the call to the remote web service
 * It creates the stub and fill the parameters
 * The call is done in a separate thread and the results
 * are delivered asynchronoulsy via PosterListener
 */
public class Poster implements Runnable {
	// true if IO thread is running, false if not
	private boolean isThreadRunning = false;
	// The listener
	private PosterListener listener;	
	private String nation;
	private String endPoint;
	
    public Poster(PosterListener _listener, String _endPoint) {
		if (_listener == null) {
			throw new IllegalArgumentException("Listener cannot be null");
		}
		endPoint = _endPoint;
		listener = _listener;
	}	

	/**
	 * Start the WebService call in a separate thread.
	 * It checks that only one call is active at the same time
	 */
	public synchronized void requestCapital(String _country) {
		if (!isThreadRunning) {
			isThreadRunning = true;
			this.nation = _country;
			new Thread(this).start();
		}		
	}

	/**
	 * This is an IO operation and thus is executed in a
	 * separate thread
	 */
	public void run() {
		CapitalBinding_Stub capitalServiceStub = new CapitalBinding_Stub();
		capitalServiceStub._setProperty(Stub.ENDPOINT_ADDRESS_PROPERTY, endPoint);
		
		CapitalPortType capitalService = (CapitalPortType)capitalServiceStub;
		try {			
			String capital = capitalService.getCapital(nation);
			listener.onCapitalRequestComplete(nation, capital);
		} catch (RemoteException e) {
			listener.onCapitalRequestError(e.getMessage());
		}
	}
	
}
